@@ -1,6 +1,7 @@
 from .utils import appdir
 import g4f
 from importlib import metadata
+import logging
 
 try:
     __version__ = metadata.version("python-tgpt")
@@ -27,6 +28,7 @@ tgpt_providers = [
     "groq",
     "perplexity",
     "yepchat",
+    "novita",
 ]
 
 gpt4free_providers = [
@@ -39,3 +41,6 @@ __all__ = [
     "appdir",
     "imager",
 ] + available_providers
+
+logging.getLogger("httpx").setLevel(logging.ERROR)
+logging.getLogger("websocket").setLevel(logging.ERROR)
